@@ -18,7 +18,7 @@ import evalidate
 import socket
 from socket import AF_INET, SOCK_STREAM, SOCK_DGRAM
 
-version='2.0.48 (traceback)'
+version='2.0.58 (seqlist)'
 
 
 # TODO
@@ -30,9 +30,11 @@ version='2.0.48 (traceback)'
 class OkerrExc(Exception):
     pass
 
-class OkerrClientServer(OkerrExc):
+class OkerrLockError(OkerrExc):
     pass
 
+class OkerrClientServer(OkerrExc):
+    pass
     
 class OkerrKeyAuth(OkerrExc):
     pass
