@@ -198,6 +198,7 @@ class TaskSeq():
     # to route element
     # 
     def mkargs(self,s):
+              
         if isinstance(s,six.string_types):
             try:
                 m = shlex.split(s)[0]
@@ -903,6 +904,7 @@ class TaskMkSeq(GenTaskProcessor):
         
     def mkroute(self,ts,data):
         route = list()
+        
         for k in sorted(data, key=int):
             e = data[k]
             #etpl = string.Template(e)            
@@ -910,7 +912,7 @@ class TaskMkSeq(GenTaskProcessor):
                         
             args = ts.mkargs(e)
                        
-            cmd = args['command']
+            # cmd = args['command']
                                     
 #            for defarg in ts.tp[cmd].defargs:
 #                if not defarg in e:
@@ -986,9 +988,20 @@ class TaskMkSeq(GenTaskProcessor):
 
     
         if v is None:
-            v=dict()        
+            v=dict()   
+                        
+
+        if isinstance(data,list):
+            ddata={}
+            # convert data to dict
+            for i,s in zip(xrange(10,10000,10),data):
+                ss = s.strip()
+                if ss:
+                    ddata[i] = ss
+            data = ddata
+                 
         
-        if hasdict(data):
+        if isinstance(data,dict) and hasdict(data):
             for sdname,subdata in data.items():
                 if isinstance(subdata,str):
                     v[sdname]=subdata    
